# SLC01 - SDLC Overview

Tổng quan về Software Development Life Cycle (SDLC).

## Best Practices

| # | Best Practice | Mô tả |
|---|---------------|-------|
| BP01 | [SDLC Phases](SLC01-BP01-SDLC-Phases.md) | Các giai đoạn trong vòng đời phát triển phần mềm |

## Tham khảo

- ISO/IEC 12207 - Software Life Cycle Processes
- AWS SDLC Guide
- IEEE Software Engineering Standards
